@@ -32,7 +32,7 @@
  * authorization of the copyright holder.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "indic-ot.h"
 #include "mprefixups.h"
@@ -143,27 +143,6 @@ static void noteBaseConsonant(Output *output)
     }
 }
 
-static void swapChars(Output *output, int a, int b)
-{
-    if (output->fOutChars != NULL) {
-	gunichar temp_char;
-	guint32 temp_index;
-	gulong temp_tag;
-
-	temp_char = output->fOutChars[output->fOutIndex + b];
-	temp_index = output->fCharIndices[output->fOutIndex + b];
-	temp_tag = output->fCharTags[output->fOutIndex + b];
-
-	output->fOutChars[output->fOutIndex + b] = output->fOutChars[output->fOutIndex + a];
-	output->fCharIndices[output->fOutIndex + b] = output->fCharIndices[output->fOutIndex + a];
-	output->fCharTags[output->fOutIndex + b] = pstf_p;
-
-	output->fOutChars[output->fOutIndex + a] = temp_char;
-	output->fCharIndices[output->fOutIndex + a] = temp_index;
-	output->fCharTags[output->fOutIndex + a] = temp_tag;
-    }
-}
-
 static void writeChar(Output *output, gunichar ch, guint32 charIndex, gulong charTags)
 {
     if (output->fOutChars != NULL) {
@@ -280,6 +259,12 @@ glong indic_ot_reorder(const gunichar *chars, const glong *utf8_offsets, glong c
 	case CC_NUKTA:
 	case CC_VIRAMA:
 	case CC_AL_LAKUNA:
+	    /* patch for rendering fix for Malayalam SAMVRUTHOKARA by suresh */
+	    if (chars[prev - 1] == 0x0D41) {
+	       	 writeChar(&output, chars[prev], prev, blwf_p);
+		 break;
+	    }
+	    /* end patch */
 	    writeChar(&output, C_DOTTED_CIRCLE, prev, blwf_p);
 	    writeChar(&output, chars[prev], prev, blwf_p);
 	    break;
