@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "pango-fontmap.h"
 #include "pangoatsui-private.h"
@@ -43,11 +43,11 @@ struct _PangoATSUIFamily
 
 #define PANGO_TYPE_ATSUI_FAMILY              (pango_atsui_family_get_type ())
 #define PANGO_ATSUI_FAMILY(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_ATSUI_FAMILY, PangoATSUIFamily))
-#define PANGO_ATSUI_IS_FAMILY(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_ATSUI_FAMILY))
+#define PANGO_IS_ATSUI_FAMILY(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_ATSUI_FAMILY))
 
 #define PANGO_TYPE_ATSUI_FACE              (pango_atsui_face_get_type ())
 #define PANGO_ATSUI_FACE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_ATSUI_FACE, PangoATSUIFace))
-#define PANGO_ATSUI_IS_FACE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_ATSUI_FACE))
+#define PANGO_IS_ATSUI_FACE(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), PANGO_TYPE_ATSUI_FACE))
 
 struct _PangoATSUIFace
 {
@@ -62,6 +62,7 @@ struct _PangoATSUIFace
 
   int weight;
   int traits;
+  guint synthetic_italic : 1;
 };
 
 static GType pango_atsui_family_get_type (void);
@@ -98,18 +99,30 @@ pango_atsui_family_list_faces (PangoFontFamily  *family,
 			       int              *n_faces)
 {
   PangoATSUIFamily *atsuifamily = PANGO_ATSUI_FAMILY (family);
-  NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
 
   if (atsuifamily->n_faces < 0)
     {
+      NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
       const char *real_family = get_real_family (atsuifamily->family_name);
-      NSArray *members = [[NSFontManager sharedFontManager] availableMembersOfFontFamily:[NSString stringWithUTF8String:real_family]];
-      int i;
+      NSFontManager *manager = [NSFontManager sharedFontManager];
+      NSArray *members = [manager availableMembersOfFontFamily:[NSString stringWithUTF8String:real_family]];
+      int i, count;
+      GHashTable *hash_table;
+      GList *faces = NULL, *l;
+      GList *synthetic_faces = NULL;
 
-      atsuifamily->n_faces = [members count];
-      atsuifamily->faces = g_new (PangoFontFace *, atsuifamily->n_faces);
+      /* The NSFontManager API returns italic faces for some families
+       * even if they don't exist. When using Cocoa to create
+       * instances of those fonts, Cocoa synthesizes italic versions
+       * by applying a shear transformation. We do that manually for
+       * those fonts in pangocairo-atsuifont.c. For many other fonts,
+       * there is no italic face at all, so we create synthesized
+       * versions of those like in the win32 and fontconfig backends.
+       */
+      hash_table = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-      for (i = 0; i < atsuifamily->n_faces; i++)
+      count = [members count];
+      for (i = 0; i < count; i++)
 	{
 	  PangoATSUIFace *face = g_object_new (PANGO_TYPE_ATSUI_FACE, NULL);
 	  NSArray *font_array = [members objectAtIndex:i];
@@ -120,8 +133,48 @@ pango_atsui_family_list_faces (PangoFontFamily  *family,
 	  face->weight = [[font_array objectAtIndex:2] intValue];
 	  face->traits = [[font_array objectAtIndex:3] intValue];
 
-	  atsuifamily->faces[i] = (PangoFontFace *)face;
+	  faces = g_list_prepend (faces, face);
+
+	  if (face->traits & NSItalicFontMask)
+	    g_hash_table_insert (hash_table, GINT_TO_POINTER (face->weight), face);
 	}
+
+      for (l = faces; l; l = l->next)
+	{
+	  PangoATSUIFace *face = l->data;
+
+	  if (!g_hash_table_lookup (hash_table, GINT_TO_POINTER (face->weight)))
+	    {
+	      PangoATSUIFace *italic_face = g_object_new (PANGO_TYPE_ATSUI_FACE, NULL);
+
+	      italic_face->family = atsuifamily;
+	      italic_face->postscript_name = g_strdup (face->postscript_name);
+	      italic_face->weight = face->weight;
+	      italic_face->traits = face->traits | NSItalicFontMask;
+	      italic_face->synthetic_italic = TRUE;
+
+	      /* Try to create a sensible face name. */
+	      if (strcasecmp (face->style_name, "regular") == 0)
+		italic_face->style_name = g_strdup ("Oblique");
+	      else 
+		italic_face->style_name = g_strdup_printf ("%s Oblique", face->style_name);
+
+	      synthetic_faces = g_list_prepend (synthetic_faces, italic_face);
+	    }
+	}
+
+      faces = g_list_concat (faces, synthetic_faces);
+
+      atsuifamily->n_faces = g_list_length (faces);
+      atsuifamily->faces = g_new (PangoFontFace *, atsuifamily->n_faces);
+
+      for (l = faces, i = 0; l; l = l->next, i++)
+	atsuifamily->faces[i] = l->data;
+
+      g_list_free (faces);
+      g_hash_table_destroy (hash_table);
+
+      [pool release];
     }
 
   if (n_faces)
@@ -129,8 +182,6 @@ pango_atsui_family_list_faces (PangoFontFamily  *family,
 
   if (faces)
     *faces = g_memdup (atsuifamily->faces, atsuifamily->n_faces * sizeof (PangoFontFace *));
-
-  [pool release];
 }
 
 static const char *
@@ -159,9 +210,7 @@ pango_atsui_family_finalize (GObject *object)
   if (family->n_faces != -1)
     {
       for (i = 0; i < family->n_faces; i++)
-	{
-	  g_object_unref (family->faces[i]);
-	}
+	g_object_unref (family->faces[i]);
 
       g_free (family->faces);
     }
@@ -198,7 +247,7 @@ pango_atsui_family_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
@@ -266,6 +315,7 @@ pango_atsui_face_describe (PangoFontFace *face)
 
   pango_font_description_set_weight (description, pango_weight);
   pango_font_description_set_style (description, pango_style);
+  pango_font_description_set_variant (description, pango_variant);
 
   return description;
 }
@@ -301,6 +351,14 @@ pango_atsui_face_finalize (GObject *object)
   G_OBJECT_CLASS (pango_atsui_face_parent_class)->finalize (object);
 }
 
+static gboolean
+pango_atsui_face_is_synthesized (PangoFontFace *face)
+{
+  PangoATSUIFace *atsuiface = PANGO_ATSUI_FACE (face);
+
+  return atsuiface->synthetic_italic;
+}
+
 static void
 pango_atsui_face_class_init (PangoFontFaceClass *class)
 {
@@ -313,6 +371,7 @@ pango_atsui_face_class_init (PangoFontFaceClass *class)
   class->describe = pango_atsui_face_describe;
   class->get_face_name = pango_atsui_face_get_face_name;
   class->list_sizes = pango_atsui_face_list_sizes;
+  class->is_synthesized = pango_atsui_face_is_synthesized;
 }
 
 GType
@@ -320,7 +379,7 @@ pango_atsui_face_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
@@ -349,6 +408,12 @@ _pango_atsui_face_get_postscript_name (PangoATSUIFace *face)
   return face->postscript_name;
 }
 
+gboolean
+_pango_atsui_face_get_synthetic_italic (PangoATSUIFace *face)
+{
+  return face->synthetic_italic;
+}
+
 PangoCoverage *
 _pango_atsui_face_get_coverage (PangoATSUIFace *face,
 				PangoLanguage  *language)
@@ -532,18 +597,17 @@ pango_atsui_font_map_add (PangoATSUIFontMap *atsuifontmap,
 {
   FontHashKey key;
   FontHashKey *key_copy;
+  PangoATSUIFace *face;
 
-  g_assert (atsuifont->fontmap == NULL);
-
-  atsuifont->fontmap = g_object_ref (atsuifontmap);
+  _pango_atsui_font_set_font_map (atsuifont, atsuifontmap);
 
   font_hash_key_for_context (atsuifontmap, context, &key);
-  key.postscript_name = (char *)_pango_atsui_face_get_postscript_name (atsuifont->face);
-  key.desc = atsuifont->desc;
+  face = _pango_atsui_font_get_face (atsuifont);
+  key.postscript_name = (char *)_pango_atsui_face_get_postscript_name (face);
+  key.desc = _pango_atsui_font_get_font_description (atsuifont);
 
   key_copy = font_hash_key_copy (&key);
-  atsuifont->context_key = key_copy->context_key;
-  atsuifont->matrix = key.matrix;
+  _pango_atsui_font_set_context_key (atsuifont, key_copy->context_key);
   g_hash_table_insert (atsuifontmap->font_hash, key_copy, g_object_ref (atsuifont));
 }
 
@@ -562,6 +626,38 @@ pango_atsui_font_map_lookup (PangoATSUIFontMap    *atsuifontmap,
   return g_hash_table_lookup (atsuifontmap->font_hash, &key);
 }
 
+static gboolean
+find_best_match (PangoATSUIFamily            *font_family,
+		 const PangoFontDescription  *description,
+		 PangoFontDescription       **best_description,
+		 PangoATSUIFace             **best_face)
+{
+  PangoFontDescription *new_desc;
+  int i;
+
+  *best_description = NULL;
+  *best_face = NULL;
+
+  for (i = 0; i < font_family->n_faces; i++)
+    {
+      new_desc = pango_font_face_describe (font_family->faces[i]);
+
+      if (pango_font_description_better_match (description, *best_description, new_desc))
+	{
+	  pango_font_description_free (*best_description);
+	  *best_description = new_desc;
+	  *best_face = (PangoATSUIFace *)font_family->faces[i];
+	}
+      else
+	pango_font_description_free (new_desc);
+    }
+
+  if (*best_description)
+    return TRUE;
+
+  return FALSE;
+}
+
 static PangoFont *
 pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
 				PangoContext               *context,
@@ -572,52 +668,31 @@ pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
   gchar *name;
   gint size;
 
-  g_return_val_if_fail (description != NULL, NULL);
-
   size = pango_font_description_get_size (description);
-
   if (size < 0)
     return NULL;
 
   name = g_utf8_casefold (pango_font_description_get_family (description), -1);
   font_family = g_hash_table_lookup (atsuifontmap->families, name);
-
   g_free (name);
 
   if (font_family)
     {
-      PangoFontDescription *best_desc = NULL, *new_desc;
-      PangoATSUIFace *best_face = NULL;
+      PangoFontDescription *best_description;
+      PangoATSUIFace *best_face;
       PangoATSUIFont *best_font;
-      int i;
 
       /* Force a listing of the available faces */
       pango_font_family_list_faces ((PangoFontFamily *)font_family, NULL, NULL);
 
-      for (i = 0; i < font_family->n_faces; i++)
-	{
-	  new_desc = pango_font_face_describe (font_family->faces[i]);
-
-	  if (pango_font_description_better_match (description, best_desc, new_desc))
-	    {
-	      pango_font_description_free (best_desc);
-	      best_desc = new_desc;
-	      best_face = (PangoATSUIFace *)font_family->faces[i];
-	    }
-	  else
-	    {
-	      pango_font_description_free (new_desc);
-	    }
-	}
-
-      if (best_desc == NULL || best_face == NULL)
+      if (!find_best_match (font_family, description, &best_description, &best_face))
 	return NULL;
-
-      pango_font_description_set_size (best_desc, size);
+      
+      pango_font_description_set_size (best_description, size);
 
       best_font = pango_atsui_font_map_lookup (atsuifontmap, 
 					       context, 
-					       best_desc, 
+					       best_description, 
 					       best_face);
 
       if (best_font)
@@ -628,16 +703,16 @@ pango_atsui_font_map_load_font (PangoFontMap               *fontmap,
 
 	  klass = PANGO_ATSUI_FONT_MAP_GET_CLASS (atsuifontmap);
 	  best_font = klass->create_font (atsuifontmap, context, 
-					  best_face, best_desc);
+					  best_face, best_description);
 	  
 	  if (best_font)
 	    pango_atsui_font_map_add (atsuifontmap, context, best_font);
 	    /* TODO: Handle the else case here. */
 	}
 
-      pango_font_description_free (best_desc);
+      pango_font_description_free (best_description);
 
-      return PANGO_FONT (best_font);
+      return (PangoFont *)best_font;
     }
 
   return NULL;
